Stan Math Library: stan/math/prim/arr/fun/fill.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

fill.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_ARR_FUN_FILL_HPP
2 #define STAN_MATH_PRIM_ARR_FUN_FILL_HPP
3
4 #include <stan/math/prim/scal/fun/fill.hpp>
5 #include <vector>
6
7 namespace stan {
8 namespace math {
9
21 template <typename T, typename S>
22 void fill(std::vector<T>& x, const S& y) {
23 for (size_t i = 0; i < x.size(); ++i)
24 fill(x[i], y);
25 }
26
27 }
28 }
29 #endif
fill.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::fill
void fill(std::vector< T > &x, const S &y)
Fill the specified container with the specified value.
Definition: fill.hpp:22

[ Stan Home Page ] © 2011–2016, Stan Development Team.